@@ -232,7 +232,7 @@ export class Lattice extends InMemoryEntity implements LatticeSchema {
         // preserve the new type and scale back the lattice parameters
         const k = latticeConfig.a / newLattice.a;
 
-        return Object.assign(newLattice, {
+        return Object.assign(newLattice.toJSON(), {
             a: f_(newLattice.a * k),
             b: f_(newLattice.b * k),
             c: f_(newLattice.c * k),
